import React, {useState} from 'react';
import PropTypes from 'prop-types';
import {View, StyleSheet, Text} from 'react-native';
import {color} from '../styles';
import {IconButton} from 'react-native-paper';
import RNDateTimePicker from '@react-native-community/datetimepicker';

export default function Datepicker(props) {
  const {
    index,
    groupindex,
    name,
    value,
    meta,
    style,
    onChangeInputValue,
    isMandatory,
    fieldTitleFontStyle,
    iconColor,
  } = props;

  const [datePicker, setDatePicker] = useState(false);
  const [date, setDate] = useState(new Date());

  function showDatePicker() {
    setDatePicker(true);
  }

  function onDateSelected(event, value) {
    setDate(value);
    setDatePicker(false);
    onChangeInputValue(value.toString());
    const date = new Date();
    const datestr = value.toString();
  }

  return (
    <View style={style}>
      <View>
        <View style={styles.fieldheader}>
          <Text style={styles.text(fieldTitleFontStyle)}>
            {`${meta.text || meta.title} ${isMandatory ? '*' : ''}`}
          </Text>
        </View>
        <View style={styles.MainContainer}>
          <Text style={styles.text1}>{date.toDateString()}</Text>

          {datePicker && (
            <RNDateTimePicker
              value={date}
              mode={'date'}
              display={'default'}
              is24Hour={true}
              onChange={onDateSelected}
              style={styles.datePicker}
            />
          )}

          <View>
            <IconButton
              icon="calendar"
              color={iconColor ? iconColor : 'green'}
              onPress={showDatePicker}
            />
          </View>
        </View>
      </View>
    </View>
  );
}

const styles = StyleSheet.create({
  text: fieldTitleFontStyle => ({
    margin: 10,
    ...fieldTitleFontStyle,
  }),
  fieldheader: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  MainContainer: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center',
  },
  text1: {
    color: 'black',
    padding: 10,
    textAlign: 'center',
    width: '85%',
    borderColor: color.GREY,
    borderWidth: 1,
    borderRadius: 3,
    marginLeft: 10,
  },
  // Style for iOS ONLY...
  datePicker: {
    justifyContent: 'center',
    alignItems: 'flex-start',
    width: 320,
    height: 260,
    display: 'flex',
  },
});

Datepicker.propTypes = {
  index: PropTypes.number,
  groupindex: PropTypes.number,
  name: PropTypes.string.isRequired,
  meta: PropTypes.object.isRequired,
  value: PropTypes.string,
  style: PropTypes.object,
  onChangeInputValue: PropTypes.func,
  isMandatory: PropTypes.bool,
  fieldTitleFontStyle: PropTypes.object,
  iconColor: PropTypes.string,
};
