import React, {useState} from 'react';
import PropTypes from 'prop-types';
import {
  Text,
  View,
  StyleSheet,
  Platform,
  TextInput,
  Dimensions,
} from 'react-native';
import {Button, IconButton, Switch, DataTable} from 'react-native-paper';
import {color} from '../styles';
import SelectDropdown from 'react-native-select-dropdown';
import Icon from 'react-native-vector-icons/Feather';
import {CheckBox} from 'react-native-elements';

export default function DropDown(props) {
  const {
    name,
    meta,
    isMandatory,
    onChangeInputValue,
    index,
    groupindex,
    fieldTitleFontStyle,
  } = props;

  const [open, setOpen] = useState(true);

  const onSelectItem = item => onChangeInputValue(item);

  const onForcus = () => {
    setOpen(false);
  };

  const onBlur = () => {
    setOpen(true);
  };

  return (
    <View
      key={name}
      style={[Platform.OS === 'ios' && styles.overrideOtherComponent(index)]}>
      <View style={styles.fieldheader}>
        <Text style={styles.text(fieldTitleFontStyle)}>{`${meta.title} ${
          isMandatory ? '*' : ''
        }`}</Text>
      </View>
      <View>
        <SelectDropdown
          data={meta.items}
          onSelect={onSelectItem}
          dropdownStyle={styles.dropdown}
          rowTextStyle={{fontSize: 15}}
          buttonStyle={styles.buttonStyle}
          buttonTextStyle={{color: color.BLACK, fontSize: 15}}
          selectedRowStyle={{backgroundColor: color.GREY}}
          selectedRowTextStyle={{color: 'white'}}
          renderDropdownIcon={
            open
              ? () => <Icon name="chevron-down" size={18} color="#000" />
              : () => <Icon name="chevron-up" size={18} color="#000" />
          }
          dropdownIconPosition="right"
          onFocus={onForcus}
          onBlur={onBlur}
          // search={true}
        />
      </View>
    </View>
  );
}

const styles = StyleSheet.create({
  overrideOtherComponent: index => ({
    zIndex: 99 - index,
  }),
  text: fieldTitleFontStyle => ({
    marginLeft: 10,
    marginTop: 10,
    marginBottom: 10,
    ...fieldTitleFontStyle,
  }),
  fieldheader: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  dropdown: {
    borderRadius: 5,
    borderColor: 'black',
    borderWidth: 1,
  },
  buttonStyle: {
    marginHorizontal: '2.5%',
    marginBottom: 10,
    borderRadius: 5,
    width: '95%',
    borderColor: color.GREY,
    borderWidth: 1,
    backgroundColor: 'white',
  },
});

DropDown.propTypes = {
  name: PropTypes.string.isRequired,
  meta: PropTypes.object.isRequired,
  index: PropTypes.number,
  onChangeInputValue: PropTypes.func,
  isMandatory: PropTypes.bool,
  groupindex: PropTypes.number,
  fieldTitleFontStyle: PropTypes.object,
};
