/* eslint-disable prettier/prettier */
import React, {useState, useEffect} from 'react';
import PropTypes from 'prop-types';
import {View, StyleSheet, Text} from 'react-native';
import {color} from '../styles';
import {IconButton} from 'react-native-paper';
import DocumentPicker, {
  DocumentPickerResponse,
  isInprogress,
  types,
} from 'react-native-document-picker';

export default function Filepicker(props) {
  const {
    index,
    groupindex,
    name,
    value,
    meta,
    style,
    onChangeInputValue,
    isMandatory,
    fieldTitleFontStyle,
    iconColor,
  } = props;
  const [result, setResult] = useState(null);

  useEffect(() => {
    if (result && result[0].name) {
      onChangeInputValue(result[0].name);
    }
  }, [result]);

  const handleError = err => {
    if (DocumentPicker.isCancel(err)) {
      console.warn('cancelled');
    } else if (isInprogress(err)) {
      console.warn(
        'multiple pickers were opened, only the last will be considered',
      );
    } else {
      throw err;
    }
  };

  return (
    <View style={style}>
      <View>
        <View style={styles.fieldheader}>
          <Text style={styles.text(fieldTitleFontStyle)}>{`${meta.text || meta.title} ${
            isMandatory ? '*' : ''
          }`}</Text>
        </View>
        <View style={styles.MainContainer}>
          <Text style={styles.filename}>{result && result[0].name ? result[0].name : 'Select file'}</Text>
          <View>
            <IconButton icon="file" color={iconColor ? iconColor : 'green'} onPress={
              () => {
                DocumentPicker.pick({
                  type: types.images,
                })
                  .then(setResult)
                  .catch(handleError);
              }
            } />
          </View>
        </View>
        {/* <Text selectable>Result: {JSON.stringify(result, null, 2)}</Text> */}
      </View>
    </View>
  );
}

const styles = StyleSheet.create({
  text: fieldTitleFontStyle => ({
    margin: 10,
    ...fieldTitleFontStyle,
  }),
  fieldheader: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
  MainContainer: {
    flex: 1,
    flexDirection: 'row',
    alignItems: 'center',
  },
  filename: {
    width: '85%',
    borderColor: color.GREY,
    borderWidth: 1,
    borderRadius: 3,
    padding: 10,
    marginLeft: 10,
    textAlign: 'center',
  },
});

Filepicker.propTypes = {
  index: PropTypes.number,
  groupindex: PropTypes.number,
  name: PropTypes.string.isRequired,
  meta: PropTypes.object.isRequired,
  value: PropTypes.string,
  style: PropTypes.object,
  onChangeInputValue: PropTypes.func,
  isMandatory: PropTypes.bool,
  fieldTitleFontStyle: PropTypes.object,
  iconColor: PropTypes.string,
};
