import React from 'react';
import PropTypes from 'prop-types';
import {View, StyleSheet, TextInput, Text} from 'react-native';
import {color} from '../styles';

export default function InputText(props) {
  const {
    index,
    groupindex,
    name,
    value,
    meta,
    style,
    onChangeInputValue,
    isMandatory,
    fieldTitleFontStyle,
  } = props;

  return (
    <View key={name}>
      <View style={styles.fieldheader}>
        <Text style={styles.text(fieldTitleFontStyle)}>{`${meta.title} ${
          isMandatory ? '*' : ''
        }`}</Text>
      </View>
      <TextInput
        style={{
          ...styles.textBox(meta.multiline, meta.numberOfLines),
          ...style,
        }}
        value={value || ''}
        underlineColorAndroid="transparent"
        onChangeText={onChangeInputValue}
        accessibilityLabel={`input-${meta.title}`}
        editable
        placeholder={meta.placeholder}
        multiline={meta.multiline}
        numberOfLines={meta.numberOfLines}
      />
    </View>
  );
}

const styles = StyleSheet.create({
  text: fieldTitleFontStyle => ({
    marginLeft: 10,
    marginTop: 10,
    ...fieldTitleFontStyle,
  }),
  textBox: (multiline, numberOfLines) => ({
    height: !multiline ? 40 : 40 * numberOfLines,
    borderColor: color.GREY,
    borderWidth: 1,
    borderRadius: 3,
    margin: 10,
    paddingLeft: 10,
  }),
  fieldheader: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
  },
});

InputText.propTypes = {
  index: PropTypes.number,
  groupindex: PropTypes.number,
  name: PropTypes.string.isRequired,
  meta: PropTypes.object.isRequired,
  value: PropTypes.string,
  style: PropTypes.object,
  onChangeInputValue: PropTypes.func,
  isMandatory: PropTypes.bool,
  fieldTitleFontStyle: PropTypes.object,
};
