/**
 * Sample React Native App
 * https://github.com/facebook/react-native
 *
 * @format
 * @flow strict-local
 */

import React, {useEffect, useState} from 'react';
import type {Node} from 'react';
import {
  ScrollView,
  StyleSheet,
  Text,
  View,
  Dimensions,
  TouchableOpacity,
} from 'react-native';
import {componentName, skipValidationForFields} from './constant';
import Fieldheader from './components/Fieldheader';
import {getComponent, getValidator} from './componentMap';
import {color} from './styles';
import PropTypes from 'prop-types';

const screenHeight = Dimensions.get('window').height;

const FormRender: () => Node = ({
  setFormData,
  submit,
  title,
  titleBarEnable,
  titleBarStyle,
  titleTextStyle,
  submitButtonStyle,
  sectionTitleFontStyle,
  sectionStyle,
  fieldTitleFontStyle,
  iconColor,
  headerStyle,
}) => {
  const formtemplate1 = setFormData;
  const titleBarStatus = titleBarEnable ? 'true' : 'false';
  console.log(titleBarEnable);
  console.log('setFormData', setFormData);

  const onSubmit = fieldsdata => {
    submit(fieldsdata);
  };

  const [formFields, setFormFields] = useState({});
  const [isValidFormFields, setValid] = useState(false);
  const mandatoryFields = formtemplate1.data.filter(data => data.is_mandatory);

  useEffect(() => {
    formtemplate1.data.sort((a, b) => a.index - b.index);
    setFormFields({
      ...formFields,
      ...setDefaultForFields(),
    });
  }, []);

  useEffect(() => {
    const isValid = checkAllMandatoryFields();
    setValid(isValid);
  }, [JSON.stringify(formFields)]);

  const onChangeInputValue = (fieldName, inputType) => value => {
    setFormFields({
      ...formFields,
      [fieldName]: {
        ...(formFields[fieldName] || {}),
        value,
        inputType,
      },
    });
  };

  const setDefaultForFields = () => {
    const fields = {};
    formtemplate1.data.forEach(data => {
      if (data.component === componentName.CHECKBOX) {
        fields[data.field_name] = {
          value: false,
          inputType: data.component,
        };
      }
      if (data.component === componentName.DATE_PICKER) {
        const today = new Date();
        const currentDate =
          `${today.getFullYear()}-${`0${today.getMonth() + 1}`.slice(-2)}-` +
          `${today.getDate()}`;

        fields[data.field_name] = {
          value: currentDate,
          inputType: data.component,
        };
      }
      if (data.component === componentName.TIME_PICKER) {
        const today = new Date();
        const currentTime =
          `${today.getHours()}:${`0${today.getMinutes()}`.slice(-2)}:` +
          `${today.getSeconds()}`;

        fields[data.field_name] = {
          value: currentTime,
          inputType: data.component,
        };
      }
    });

    return fields;
  };

  const getValue = element => formFields[element.field_name]?.value;

  const onSumbitButtonPress = () => {
    onSubmit(formFields);
    // setFormFields({});
  };

  const checkAllMandatoryFields = () => {
    for (const field of mandatoryFields) {
      const key = field.field_name;

      if (skipValidationForFields.includes(field.component)) {
        continue;
      }

      const data = formFields[key];
      const validator = data && getValidator(data.inputType);

      if (
        !data ||
        ((!data.value || (validator && !validator(data.value, key))) &&
          data.value !== false &&
          data.value !== 0)
      ) {
        return false;
      }
    }

    return true;
  };

  return (
    <View>
      {titleBarStatus === 'true' && (
        <View style={styles.titlebar(titleBarStyle)}>
          <Text style={styles.titlebarText(titleTextStyle)}>
            {title ? title : 'Form Render'}
          </Text>
        </View>
      )}
      <View
        style={
          titleBarStyle && titleBarStyle.height
            ? {maxHeight: screenHeight - titleBarStyle.height}
            : {maxHeight: screenHeight - 60}
        }>
        <ScrollView contentInsetAdjustmentBehavior="automatic">
          <View style={styles.container}>
            {formtemplate1 &&
              formtemplate1.data.map((element, i) => {
                if (element.component === componentName.GROUP) {
                  return (
                    <View key={i}>
                      <Fieldheader
                        // onRef={ref => (this.parentReference = ref)}
                        index={element.index}
                        title={element.title}
                        sectionTitleFontStyle={sectionTitleFontStyle}
                      />
                      <View
                        style={
                          element.childs.length > 0
                            ? styles.group(sectionStyle)
                            : {}
                        }>
                        {element.childs.map((child, j) => {
                          const Component = getComponent(child.component);
                          return (
                            Component && (
                              <Component
                                key={j}
                                index={child.index}
                                groupindex={element.index}
                                name={child.field_name}
                                meta={child.meta}
                                style={child.style}
                                value={getValue(child)}
                                onChangeInputValue={onChangeInputValue(
                                  child.field_name,
                                  child.component,
                                )}
                                isMandatory={child.is_mandatory === 'true'}
                                fieldTitleFontStyle={fieldTitleFontStyle}
                                headerStyle={headerStyle}
                                iconColor={iconColor}
                              />
                            )
                          );
                        })}
                      </View>
                    </View>
                  );
                } else {
                  const Component = getComponent(element.component);
                  return (
                    Component && (
                      <Component
                        key={i}
                        index={element.index}
                        groupindex={0}
                        name={element.field_name}
                        meta={element.meta}
                        style={element.style}
                        value={getValue(element)}
                        onChangeInputValue={onChangeInputValue(
                          element.field_name,
                          element.component,
                        )}
                        isMandatory={element.is_mandatory === 'true'}
                        fieldTitleFontStyle={fieldTitleFontStyle}
                        headerStyle={headerStyle}
                        iconColor={iconColor}
                      />
                    )
                  );
                }
              })}
          </View>
          <TouchableOpacity
            activeOpacity={0.7}
            onPress={onSumbitButtonPress}
            disabled={!isValidFormFields}>
            <Text style={styles.buttonStyle(submitButtonStyle)}>Submit</Text>
          </TouchableOpacity>
        </ScrollView>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  group: sectionStyle => ({
    borderColor: color.GREY,
    borderRadius: 5,
    borderWidth: 1,
    marginHorizontal: 10,
    marginBottom: 10,
    paddingBottom: 10,
    ...sectionStyle,
  }),
  // titlebar: {
  //   height: 60,
  //   flexDirection: 'row',
  //   backgroundColor: '#44f',
  //   justifyContent: 'center',
  //   alignItems: 'center',
  // },
  titlebar: titleBarStyle => ({
    height: 60,
    flexDirection: 'row',
    backgroundColor: '#44f',
    justifyContent: 'center',
    alignItems: 'center',
    ...titleBarStyle,
  }),
  titlebarText: titleTextStyle => ({
    fontSize: 25,
    color: 'white',
    fontWeight: 'bold',
    ...titleTextStyle,
  }),
  buttonStyle: submitButtonStyle => ({
    borderRadius: 5,
    backgroundColor: '#44f',
    alignSelf: 'center',
    marginTop: 10,
    width: 130,
    marginHorizontal: 10,
    height: 50,
    textAlign: 'center',
    textAlignVertical: 'center',
    color: 'white',
    fontSize: 17,
    ...submitButtonStyle,
  }),
  container: {
    flex: 1,
  },
});

FormRender.propTypes = {
  setFormData: PropTypes.object.isRequired,
  submit: PropTypes.func.isRequired,
  title: PropTypes.string,
  titleBarEnable: PropTypes.bool,
  titleBarStyle: PropTypes.object,
  titleTextStyle: PropTypes.object,
  submitButtonStyle: PropTypes.object,
  sectionTitleFontStyle: PropTypes.object,
  sectionStyle: PropTypes.object,
  fieldTitleFontStyle: PropTypes.object,
  iconColor: PropTypes.string,
  headerStyle: PropTypes.object,
};

export default FormRender;
